# jgtml
JGTML

* primarily designed to analyze the effectiveness of trading signals
* designed to analyze the effectiveness of trading signals within the context of larger balance lines.


----



CLI's HELP
_____

